/*
 * File:	osdefs.h
 *
 * uC/OS Real-time multitasking kernel for the ARM processor.
 *
 * Created by Jean J. Labrosse. 
 * ARM port by Marco Graziano (marcog@crl.com).
 *
 */

/* used in boolean fields */
#define TRUE    0x1 
#define FALSE   0x0

/* disable interrupt mask */
#define NOINT   0x03

/* idle task stack size (words) */
#define OS_IDLE_STK_SIZE        32      
 
/*
 * Global variables.
 */
extern  uint    OSCtxSwCtr;             /* context switches counter */
extern  uint    OSIdleCtr;              /* idle counter */
extern  uint    OSRunning;              /* kernel running flag */
extern  OS_TCB  *OSTCBCur;              /* current running TCB pointer */
extern  OS_TCB  *OSTCBHighRdy;          /* highest priority TCB ready to run */
extern  OS_TCB  *OSTCBPrioTbl[];        /* table of pointers to created TCBs */
 
/* system call SWI numbers*/
#define OSEnterSWI              0x00

/* constants */
#define	SVC32MODE	0x13
#define TimerIRQNum     1
#define	INT_MAX		0x7FFFFFFF

/* task status */
#define	OS_STAT_RDY	0	/* ready to run */
#define	OS_STAT_SEM	1	/* suspended on semaphore */
#define	OS_STAT_MBOX	2	/* suspended on mailbox */
#define	OS_STAT_Q	3	/* suspended on queue */

#define	ENTER_CRITICAL()	OSDisableInt() 
#define	EXIT_CRITICAL()		OSEnableInt() 
